@@ -1,6 +1,6 @@
 /*
  * SPDX-License-Identifier: Apache-2.0
- * Copyright (C) 2019-2020 Intel Corporation
+ * Copyright (C) 2019-2021 Intel Corporation
  */
 
 /**
@@ -228,6 +228,16 @@ struct igsc_hw_config {
     uint8_t blob[IGSC_HW_CONFIG_BLOB_SIZE];
 };
 
+/**
+ * @brief structure to store device subsystem ids
+ * @param ssvid subsystem vendor id
+ * @param ssdid subsystem device id
+ */
+struct igsc_subsystem_ids {
+    uint16_t ssvid;
+    uint16_t ssdid;
+};
+
 /**
  * @def IGSC_MAX_IMAGE_SIZE
  * @brief Maximum firmware image size
@@ -322,6 +332,23 @@ IGSC_EXPORT
 int igsc_device_get_device_info(IN  struct igsc_device_handle *handle,
                                 OUT struct igsc_device_info *dev_info);
 
+
+/**
+ *  @brief Update device information from the firmware
+ *         The subsystem device id and the subsystem vendor id,
+ *         reported by the PCI system, may be different from the ones
+ *         reported by the firmware and so the device information
+ *         should be updated by with the values received from the firmware.
+ *
+ *  @param handle An initialized handle to the device.
+ *  @param dev_info A device info structure
+ *
+ *  @return IGSC_SUCCESS if successful, otherwise error code.
+ */
+IGSC_EXPORT
+int igsc_device_update_device_info(IN  struct igsc_device_handle *handle,
+                                   OUT struct igsc_device_info *dev_info);
+
 /**
  *  @brief Closes a GSC Firmware Update device.
  *
@@ -372,6 +399,18 @@ IGSC_EXPORT
 int igsc_device_hw_config(IN  struct igsc_device_handle *handle,
                           OUT struct igsc_hw_config *hw_config);
 
+/**
+ *  @brief Retrieves the subsystem ids (vid/did) from the device
+ *
+ *  @param handle A handle to the device.
+ *  @param hw_config The memory to store obtained subsystem ids
+ *
+ *  @return IGSC_SUCCESS if successful, otherwise error code.
+ *  @return IGSC_ERROR_NOT_SUPPORTED if feature is not supported
+ */
+IGSC_EXPORT
+int igsc_device_subsystem_ids(IN struct  igsc_device_handle *handle,
+                              OUT struct igsc_subsystem_ids *ssids);
 
 /**
  *  @brief Retrieves the hw configurations from the provided
@@ -572,11 +611,11 @@ int igsc_image_fwdata_version(IN struct igsc_fwdata_image *img,
  *  @param device_ver pointer to the device GSC data firmware version
  *
  *  @return
- *  * IGSC_VERSION_NOT_COMPATIBLE if update image is for a different platform
- *  * IGSC_VERSION_NEWER          if update image version is newer than the one on the device
- *  * IGSC_VERSION_EQUAL          if update image version is equal to the one on the device
- *  * IGSC_VERSION_OLDER          if update image version is older than the one on the device
- *  * IGSC_VERSION_ERROR          if NULL parameters were provided
+ *  * IGSC_FWDATA_VERSION_REJECT_VCN                    if image VCN version is bigger than device VCN
+ *  * IGSC_FWDATA_VERSION_REJECT_OEM_MANUF_DATA_VERSION if OEM manufacturing data version is not bigger than device OEM version
+ *  * IGSC_FWDATA_VERSION_REJECT_DIFFERENT_PROJECT      if major version is different from device major version
+ *  * IGSC_FWDATA_VERSION_ACCEPT                        if VCN version is equal to the device's one, and OEM is bigger
+ *  * IGSC_FWDATA_VERSION_OLDER_VCN                     if VCN version is smaller than the one on the device
  */
 IGSC_EXPORT
 uint8_t igsc_fwdata_version_compare(IN struct igsc_fwdata_version *image_ver,
